==> migrate_wizard-2.0.9-alpha1.tar.gz: migrate_wizard/src/Controller/OriginMediaListBuilder.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

declare(strict_types = 1);

namespace Drupal\migrate_wizard\Controller;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Provides a listing of origin node entities.
 *
 * @ingroup migrate_wizard
 */
class OriginMediaListBuilder extends ConfigEntityListBuilder {

  protected $current_mw_database;

  /**
   * {@inheritdoc}
   */
  protected $medias = [];

  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, RequestStack $request_stack) {
    parent::__construct($entity_type, $storage);
    $this->current_mw_database = $request_stack->getCurrentRequest()->get('mw_database');
  }

  /**
   * Builds the header row for the entity listing.
   *
   * @return array
   *   A render array structure of header strings.
   *
   * @see \Drupal\Core\Entity\Controller\EntityListController::render()
   */
  public function buildHeader(): array {
    $header['label'] = $this->t('Origin Media');
    $header['machine_name'] = $this->t('Machine Name');
    $header['description'] = $this->t('Description');
    $header['database'] = $this->t('Database');
    $header['source_type'] = $this->t('Source Type');

    return $header + parent::buildHeader();
  }

  /**
   * Builds a row for an entity in the entity listing.
   *
   * @param EntityInterface $entity
   *   The entity for which to build the row.
   *
   * @return array
   *   A render array of the table row for displaying the entity.
   *
   * @see \Drupal\Core\Entity\EntityListController::render()
   */
  public function buildRow(EntityInterface $entity): array {
    $entity_mw_database = $entity->get('use_env') ? getenv($entity->get('database')) : $entity->get('database');
    $row['label'] = $entity->label();
    $row['machine_name'] = $entity->id();
    $row['description'] = $entity->get('description');
    $row['database'] = $entity_mw_database;
    $row['source_type'] = $entity->get('source_type');

    return $row + parent::buildRow($entity);
  }

  public static function createInstance($container, $entity_type) {
    return new self(
      $entity_type,
      $container->get('entity_type.manager')->getStorage($entity_type->id()),
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity): array {
    $operations = parent::getDefaultOperations($entity);
    $operations['list'] = [
      'title' => $this->t('Manage Fields Origin Medias'),
      'weight' => 0,
      'url' => Url::fromRoute(
        'entity.origin_medias.origin_medias_fields',
        ['mw_database' => $this->current_mw_database->id, 'origin_bundle' => $entity->id()]
      ),
    ];

    return $operations;
  }

}

==> migrate_wizard-2.0.10-alpha1.tar.gz: migrate_wizard/src/Controller/OriginMediaListBuilder.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

declare(strict_types = 1);

namespace Drupal\migrate_wizard\Controller;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Provides a list of different MIME types of source files to migrate independently.
 *
 * @ingroup migrate_wizard
 */
class OriginMediaListBuilder extends ConfigEntityListBuilder {

 /**
  * The current mw_database.
  *
  * @var \Drupal\migrate_wizard\Entity\MWDatabase
  */
  protected $currentMwDatabase;

  /**
   * Constructs a new EntityListBuilder object.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type definition.
   * @param \Drupal\Core\Entity\EntityStorageInterface $storage
   *   The entity storage class.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   */
  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, RequestStack $request_stack) {
    parent::__construct($entity_type, $storage);
    $this->currentMwDatabase = $request_stack->getCurrentRequest()->get('mw_database');
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header['label'] = $this->t('Origin Media');
    $header['machine_name'] = $this->t('Machine Name');
    $header['description'] = $this->t('Description');
    $header['database'] = $this->t('Database');
    $header['source_type'] = $this->t('Source Type');

    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    $entityMwDatabase = $entity->get('use_env') ? getenv($entity->get('database')) : $entity->get('database');
    $row['label'] = $entity->label();
    $row['machine_name'] = $entity->id();
    $row['description'] = $entity->get('description');
    $row['database'] = $entityMwDatabase;
    $row['source_type'] = $entity->get('source_type');

    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance($container, $entity_type) {
    return new self(
      $entity_type,
      $container->get('entity_type.manager')->getStorage($entity_type->id()),
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity): array {
    $operations = parent::getDefaultOperations($entity);
    $operations['list'] = [
      'title' => $this->t('Manage Fields Origin Medias'),
      'weight' => 0,
      'url' => Url::fromRoute(
        'entity.origin_medias.origin_medias_fields',
        ['mw_database' => $this->currentMwDatabase->id, 'origin_bundle' => $entity->id()]
      ),
    ];

    return $operations;
  }
}
